@@ -27,7 +27,7 @@ class Crawler:
     def _crawling_(self, response):
         scraper = Scraper(response)
         list_href = scraper.gethref()
-        Terminal.found(list_href)
+        Terminal.found(list_href.__str__())
         if list_href.count == 0: return None
         urls = list_href.map(lambda x: x.url())
         responses = self.fetcher.get_all_pages(urls)
